@@ -21,7 +21,7 @@ from fireworks.core.fworker import FWorker
 from fireworks.utilities.dict_mods import apply_mod
 from fireworks.utilities.fw_serializers import FWSerializable, \
     recursive_serialize, recursive_deserialize, serialize_fw
-from fireworks.utilities.fw_utilities import get_my_host, get_my_ip
+from fireworks.utilities.fw_utilities import get_my_host, get_my_ip, NestedClassGetter
 
 __author__ = "Anubhav Jain"
 __copyright__ = "Copyright 2013, The Materials Project"
@@ -277,12 +277,13 @@ class Launch(FWSerializable, object):
         self.launch_id = launch_id
         self.fw_id = fw_id
 
-    def touch_history(self):
+    def touch_history(self, update_time=None):
         """
         Updates the update_at field of the state history of a Launch. Used to
          ping that a Launch is still alive.
         """
-        self.state_history[-1]['updated_on'] = datetime.datetime.utcnow()
+        udpate_time = update_time if update_time else datetime.datetime.utcnow()
+        self.state_history[-1]['updated_on'] = update_time
 
     def set_reservation_id(self, reservation_id):
         """
@@ -426,7 +427,6 @@ class Launch(FWSerializable, object):
                     return data['updated_on']
                 return data['created_on']
 
-
 class Workflow(FWSerializable):
     """
     A Workflow connects a group of FireWorks in an execution order
@@ -481,6 +481,12 @@ class Workflow(FWSerializable):
         def from_dict(cls, m_dict):
             return Workflow.Links(m_dict)
 
+        def __reduce__(self):
+            # to support Pickling of inner classes (for multi-job launcher's multiprocessing)
+            # return a class which can return this class when called with the
+            # appropriate tuple of arguments
+            return (NestedClassGetter(), (Workflow, self.__class__.__name__, ))
+
     def __init__(self, fireworks, links_dict=None, name=None, metadata=None, created_on=None,
                  updated_on=None):
         """
